"""
Common Copr code for logging
"""

import logging


def setup_script_logger(log, path):
    """
    Backend scripts should simply do:

        log = logging.getLogger(__name__)
        setup_script_logger(log, "/var/log/copr-backend/foo.log")
    """

    # Don't read copr config, just use INFO. Scripts should implement
    # some --verbose parameter for debug information
    log.setLevel(logging.INFO)

    # Drop the default handler, we will create it ourselves
    log.handlers = []

    # Print also to stderr
    stream = logging.StreamHandler()
    stream.setFormatter(logging.Formatter("%(message)s"))
    log.addHandler(stream)

    # Add file logging
    file_log = logging.FileHandler(path)
    file_log_format = "[%(asctime)s][%(levelname)6s]: %(message)s"
    file_log.setFormatter(logging.Formatter(file_log_format))
    log.addHandler(file_log)

    return log



"""
Helper methods that can be used by any part of the Copr stack.  Typically small
things that don't need to have it's own file.
"""

import os
import pwd
import sys

def script_requires_user(username):
    """
    Exit if the current system user name doesn't equal to the USERNAME argument.
    """
    actual_username = pwd.getpwuid(os.getuid())[0]
    if actual_username != username:
        msg = (
            "This script should be executed "
            "as '{0}' user, not '{1}'\n"
        ).format(
            username,
            actual_username,
        )
        sys.stderr.write(msg)
        sys.exit(1)
